# File generate by unscii.py. Not intended to be read or modified by humans.

raw_unscii_modules = ['unscii_16_transposed',
 'unscii_8_alt_transposed',
 'unscii_8_fantasy_transposed',
 'unscii_8_mcr_transposed',
 'unscii_8_tall_transposed',
 'unscii_8_thin_transposed',
 'unscii_8_transposed']